from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import Group
from django.conf import settings
from django.urls import reverse

from discussion.models import Forum


class Classroom(models.Model):
    name = models.CharField(
        max_length=255,
    )
    description = models.TextField(
        _('description'),
        blank=True,
    )
    image = models.ImageField(
        _('Image'),
        # upload_to=hash_name('course_thumbnails', 'name'),
        null=True,
        blank=True,
    )
    assistants = models.ManyToManyField(
        settings.AUTH_USER_MODEL,
        verbose_name=_('Assistants'),
        related_name='professor_classrooms',
        blank=True,
    )
    coordinators = models.ManyToManyField(
        settings.AUTH_USER_MODEL,
        verbose_name=_('Coordinators'),
        related_name='coordinator_classrooms',
        blank=True,
    )
    forum = models.ForeignKey(
        Forum,
        on_delete=models.SET_NULL,
        related_name='classrooms',
        blank=True,
        null=True,
    )
    courses = models.ManyToManyField(
        'Course',
        verbose_name=_('Course'),
        blank=True,
    )
    access_groups = models.ManyToManyField(
        Group,
        verbose_name=_('Grupos cursistas'),
        related_name='classrooms_access',
        blank=True,
    )
    group = models.ForeignKey(
        Group,
        verbose_name=_('Group'),
        on_delete=models.SET_NULL,
        related_name='classrooms',
        blank=True,
        null=True
    )

    def __str__(self):
        return '{} @ {}'.format(self.name, self.assistants.first())

    @property
    def chat_url(self):
        return '{}group/{}'.format(settings.ROCKET_CHAT['address'], self.group.chatroom.name)

    def is_assistant_or_coordinator(self, user):
        return user in (self.assistants.all() | self.coordinators.all())
