from rest_framework import viewsets
from rest_framework.permissions import IsAuthenticated

from django.db.models import Q

from courses.models import Course
from .models import Classroom
from .serializers import (
    BasicClassroomSerializer,
    ClassroomSerializer,
)
from .permissions import IsClassroomAssistantOrCoordinatorOrReadOnly


class BasicClassroomViewSet(viewsets.ReadOnlyModelViewSet):

    queryset = Classroom.objects.all()
    serializer_class = BasicClassroomSerializer
    # filter_fields = ['course']
    permission_classes = [IsAuthenticated]

    def get_queryset(self):
        queryset = super().get_queryset()

        if not self.request.user.is_superuser:
            queryset = queryset.filter(
                Q(group__in=self.request.user.groups.all())
                | Q(access_groups__in=self.request.user.groups.all())
                | Q(assistants=self.request.user)
                | Q(coordinators=self.request.user)
            )

        queryset = queryset.select_related(
            'forum',
            'group',
        )
        queryset = queryset.prefetch_related(
            'assistants',
            'coordinators',
            'courses',
            'access_groups',
            'events',
        )

        return queryset.distinct()


class ClassroomViewSet(BasicClassroomViewSet, viewsets.ModelViewSet):

    queryset = Classroom.objects.all()
    serializer_class = ClassroomSerializer
    permission_classes = [
        IsClassroomAssistantOrCoordinatorOrReadOnly,
        IsAuthenticated,
    ]

    def get_queryset(self):
        queryset = super().get_queryset()

        return queryset