from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.text import slugify


class CourseMaterial(models.Model):
    course = models.OneToOneField(
        'Course',
        models.CASCADE,
        related_name='course_material',
        verbose_name=_('Course Materials'),
    )
    text = models.TextField(
        _('Question'),
    )

    class Meta:
        unique_together = ("id", "course")

    def __unicode__(self):
        return self.course.name


def get_upload_path(instance, filename):
    filename, fileextension = filename.split(".", 2)
    filename = slugify(filename.split("/", 2)[-1])
    return '{0}/course_materials/{1}.{2}'.format(instance.course_material.course.slug, filename, fileextension)


class File(models.Model):
    title =  models.CharField(
        _('Title'),
        max_length=255,
        blank=True,
        null=True
    )
    file = models.FileField(
        upload_to=get_upload_path,
    )
    course_material = models.ForeignKey(
        CourseMaterial, models.CASCADE,
        related_name='files',
        verbose_name=_('Files'),
    )

    class Meta:
        ordering = ['-pk']
