from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils import timezone


class Event(models.Model):

    TYPES = (
        ('general', _('General Event')),
        ('course', _('Course Event')),
        ('course_start', _('Course Start Event')),
        ('course_lesson_start', _('Lesson Start Event')),
        ('course_unit_start', _('Unit Start Event')),
    )

    title = models.CharField(
        _('Title'),
        max_length=255,
    )
    text = models.TextField(
        _('text'),
        max_length=512,
        blank=True,
    )
    date_time = models.DateTimeField(
        _('Start date'),
        default=timezone.now,
    )
    type = models.CharField(
        _('Type'),
        choices=TYPES,
        default=TYPES[0][0],
        max_length=64,
    )
    course = models.ForeignKey(
        'Course',
        models.CASCADE,
        verbose_name=_('Course'),
        related_name='events',
        blank=True,
        null=True,
    )
    lesson = models.ForeignKey(
        'Lesson',
        models.CASCADE,
        verbose_name=_('Lesson'),
        related_name='events',
        blank=True,
        null=True,
    )
    unit = models.ForeignKey(
        'Unit',
        models.CASCADE,
        verbose_name=_('Unit'),
        related_name='events',
        blank=True,
        null=True,
    )
    klass = models.ForeignKey(
        'Class',
        models.CASCADE,
        verbose_name=_('Class'),
        related_name='events',
        blank=True,
        null=True,
    )
    classroom = models.ForeignKey(
        'Classroom',
        verbose_name=_('Classroom'),
        on_delete=models.CASCADE,
        related_name='events',
        blank=True,
        null=True,
    )

    def __str__(self):
        return self.title