from rest_framework import serializers

from .models import Note
from courses.models import Unit, Lesson, Course

class NoteSerializer(serializers.ModelSerializer):

    class Meta:
        model = Note
        fields = (
            'id',
            'text',
            'content_type',
            'object_id',
        )


class UnitNoteSerializer(serializers.ModelSerializer):

    user_note = NoteSerializer()

    class Meta:
        model = Unit
        fields = (
            'id',
            'title',
            'video',
            'position',
            'user_note',
        )


class LessonNoteSerializer(serializers.ModelSerializer):

    units_notes = UnitNoteSerializer(many=True)
    course = serializers.SlugRelatedField(slug_field='slug', read_only=True)

    class Meta:
        model = Lesson
        fields = (
            'id',
            'name',
            'position',
            'slug',
            'course',
            'units_notes',
        )


class CourseNoteSerializer(serializers.ModelSerializer):

    lessons_notes = LessonNoteSerializer(many=True)
    course_notes_number = serializers.IntegerField(required=False)

    class Meta:
        model = Course
        fields = (
            'id',
            'slug',
            'name',
            'lessons_notes',
            'course_notes_number',
        )
