from django.core.management.base import BaseCommand, CommandError
from django.contrib.auth import get_user_model
from django.db import transaction
from django.utils.timesince import timesince as djtimesince

from actstream import action
from actstream.models import user_stream, Action, actor_stream

from base64 import urlsafe_b64encode as ub64
from hashlib import sha1
from time import time

from courses_learning_objects.models import Answer, LearningObject
from discussion.models import Forum


User = get_user_model()


class Command(BaseCommand):
    help = 'Create Actions objects for past activities'

    @transaction.atomic
    def handle(self, *args, **options):
        answered_actions_ids = Action.objects.filter(verb='answered').values_list('action_object_object_id', flat=True)

        # Create any missing Answer action
        answers = Answer.objects.all().iterator()
        total = len(Answer.objects.all())
        count = 1

        for answer in answers:
            activity_id = answer.activity_id
            user = answer.user
            verb = 'answered'

            if str(answer.id) in answered_actions_ids:
                print('Skipped for answer id:', answer.id)
                continue

            timesince = djtimesince(answer.timestamp).encode('utf8').replace(b'\xc2\xa0', b' ').decode('utf8')

            action_tuple = action.send(user, verb=verb, action_object=answer, target=answer.activity, timesince=timesince)
            action_obj = action_tuple[0][1]
            action_obj.timestamp = answer.timestamp
            action_obj.save()

            print("Creating action for answer id: {} --- Task progress: {}/{}".format(answer.id, count, total))

            count += 1
