from modeltranslation.translator import register, TranslationOptions
from .models import Course, Lesson, Unit, ProfessorMessage
from .course_material.models import CourseMaterial, File
from .stats.models import AccessibleArea
from .videos.models import Video
from .certification.models import CertificateTemplate
from .events.models import Event


@register(Course)
class CourseTranslationOptions(TranslationOptions):
    fields = ('name', 'application', 'requirement', 'abstract', 'structure',
              'workload', 'course_load', 'pronatec', 'thumbnail', 'home_thumbnail',
              'min_percent_to_complete', 'informations', 'description')


@register(Lesson)
class LessonTranslationOptions(TranslationOptions):
    fields = ('desc', 'name', 'notes', 'slug', 'thumbnail')


@register(Unit)
class UnitTranslationOptions(TranslationOptions):
    fields = ('title', 'side_notes', 'chat_room')


@register(ProfessorMessage)
class ProfessorMessageTranslationOptions(TranslationOptions):
    fields = ('subject','message')


@register(CourseMaterial)
class CourseMaterialTranslationOptions(TranslationOptions):
    fields = ('text',)


@register(File)
class FileTranslationOptions(TranslationOptions):
    fields = ('title', 'file')


@register(AccessibleArea)
class AccessibleAreaTranslationOptions(TranslationOptions):
    fields = ('name', 'slug')


@register(CertificateTemplate)
class CertificateTemplateTranslationOptions(TranslationOptions):
    fields = ('role', 'name', 'signature_name', 'second_role', 'second_name', 'cert_logo',
              'base_logo', 'signature', 'second_signature', 'site_logo',
              'organization_name', 'text')


@register(Video)
class VideoTranslationOptions(TranslationOptions):
    fields = ('name', 'youtube_id', 'file',)


@register(Event)
class EventTranslationOptions(TranslationOptions):
    fields = ('title', 'text',)