from django.conf.urls import url, include
from django.views.generic import TemplateView

from rest_framework import routers

from .views import (
    CourseViewSet, BaseCourseProfessorViewSet,
    CourseBySlugViewSet,
    MessageBasicViewSet,
    MessageViewSet,
    MessageReadViewSet,
    MyCoursesViewSet,
    BasicLessonViewSet,
    LessonViewSet,
    CourseAuthorViewSet,
    CoursePictureUploadViewSet,
)
from .videos.views import VideoViewSet
from .course_material.views import CourseMaterialViewSet, CourseMaterialFileViewSet
from .import_export.views import ExportCourseView, ImportCourseView
from courses.workspaces.views import (
    WorkspaceViewSet,
    WorkspaceGroupViewSet,
    WorkspaceGroupAdminViewSet,
)
from courses.classes.views import (
    ClassViewSet,
    BasicClassViewSet,
)
from courses.reports.views import (
    SummaryViewSet,
    UsersByGroupViewSet,
    UsersByClassViewSet,
    UserStatsViewSet,
    UserAccessView
)
from courses.classroom.views import (
    BasicClassroomViewSet,
    ClassroomViewSet,
)
from courses.stats.views import (
    UserActionsView,
    UserActivitiesViewSet,
    UserActionsViewSet
)
from courses.notes.views import (
    NotesViewSet,
    UserNotesViewSet,
)
from courses.certification.views import (
    CourseCertificationPDFView,
)
from courses.events.views import (
    EventViewSet,
    EventFeed,
)
from courses.editor.views import (
    EditorContentFileViewSet,
)


router = routers.SimpleRouter(trailing_slash=False)
router.register(r'course', CourseViewSet, base_name='course')
router.register(r'my-courses', MyCoursesViewSet, base_name='my-courses')
router.register(r'course_material', CourseMaterialViewSet, base_name='course_material')
router.register(r'course_material_file', CourseMaterialFileViewSet, base_name='course_material_file')
router.register(r'course-by-slug', CourseBySlugViewSet, base_name='course_by_slug'),
router.register(r'videos', VideoViewSet, base_name='course_by_slug'),

# Lessons
router.register(r'basic_lesson', BasicLessonViewSet, base_name="basic_lesson")
router.register(r'course-lessons/(?P<course_id>[1-9][0-9]*)', LessonViewSet, base_name='lessons')

# Workspaces
router.register(r'workspaces', WorkspaceViewSet)
router.register(r'group', WorkspaceGroupViewSet, base_name='group')
router.register(r'group_admin', WorkspaceGroupAdminViewSet, base_name='group_admin')
router.register(r'class', ClassViewSet)
router.register(r'class_basic', BasicClassViewSet)

# Reports
# router.register(r'contract', views.ContractViewSet)
# router.register(r'class', views.ClassViewSet)
router.register(r'summary', SummaryViewSet, base_name='summary')
router.register(r'users-by-group', UsersByGroupViewSet, base_name='users-by-group')
router.register(r'users-by-class', UsersByClassViewSet, base_name='users-by-class')
router.register(r'user-reports', UserStatsViewSet, base_name='user-reports')

# router.register(r'course_carousel', views.CarouselCourseView, base_name='course_carousel')

#Professor
router.register(r'course_professor_basic', BaseCourseProfessorViewSet, base_name='course_professor')

# Messages/announcements
router.register(r'message_basic', MessageBasicViewSet, base_name='professor_message_basic')
router.register(r'message', MessageViewSet, base_name='professor_message')
router.register(r'message_read', MessageReadViewSet, base_name='professor_message_read')

# Classroom
router.register(r'classrooms', BasicClassroomViewSet, base_name='classrooms')
router.register(r'classroom', ClassroomViewSet, base_name='classroom')

# Events
router.register(r'events', EventViewSet, base_name='event')

# Stats
router.register(r'user-activities', UserActivitiesViewSet, base_name='user-activities')
router.register(r'actions-user', UserActionsViewSet, base_name='actions-user')

# Notes
router.register(r'note', NotesViewSet, base_name='note')
router.register(r'user_notes', UserNotesViewSet, base_name='user_notes')

router.register(r'editor-content-file', EditorContentFileViewSet)

app_name = 'courses'
urlpatterns = [
    # Stats (Activity Stream related functionality)
    url(r'^stats/', include('courses.stats.urls')),

    url(r'^calendar/calendar.ics$', EventFeed()),

    url(r'^course/(?P<course_id>[1-9][0-9]*)/export/$', ExportCourseView.as_view(), name="course_export"),
    url(r'^course/import/$', ImportCourseView.as_view(), name="course_import"),
    url(r'^', include(router.urls)),

    url(r'^user-access', UserAccessView.as_view(), name='user-access'),

    url(r'^certificate/(?P<slug>[-a-zA-Z0-9_]+)/pdf/$',
        CourseCertificationPDFView.as_view(template_name="certificate_pdf.html"),
        name='certificate-pdf',
    ),
]
