from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.text import slugify


def get_upload_path(instance, filename):
    filename, fileextension = filename.split(".", 2)
    filename = slugify(filename.split("/", 2)[-1])
    return 'course_videos/{0}.{1}'.format(filename, fileextension)

class Video(models.Model):
    name = models.CharField(
        max_length=255,
    )
    youtube_id = models.CharField(
        max_length=100,
    )
    file = models.FileField(
        upload_to=get_upload_path,
        default=None,
        null=True,
    )

    class Meta:
        verbose_name = _('Video')
        verbose_name_plural = _('Videos')

    def __unicode__(self):
        if self.unit.first():
            unit = self.unit.first()
            if unit.lesson:
                return u'Aula: {0} | Unidade: {1} | id youtube: {2}'.format(
                    unit.lesson, unit, self.youtube_id)
        return self.youtube_id
